#!/usr/bin/python3
import sys
import os
import os.path
import math


def validate(ipaddress):
    iparray = ipaddress.split('.')
    if len(iparray) != 4:
        return False
    for ipdigit in iparray:
        if not ipdigit.isdigit():
            return False
        i = int(ipdigit)
        if i < 0 or i > 255:
            return False
    return True

# 'config.sh = 1 x NIC DHCP (1)
# 'config.sh [ip][mask][gate][network][cast][dns] = 1 x NIC STATIC (7)

# 'config.sh [ip2][mask2] = 2 x NIC DHCP (3)
# 'config.sh [ip][mask][gate][network][cast][dns][ip2][mask2] = 2 x NIC STATIC (9)

TOTAL = len(sys.argv)

# Hardware can report the NIC's as different names as a result of the BIOS so we need to find the name of the actual LAN NIC
# NUC LAN NIC = enp2s0
NIC = os.popen('ls /sys/class/net').read()
NIC = NIC.split('\n')
USBNIC = NIC
for line in NIC:
    if 'lo' not in line and 'vir' not in line and 'wl' not in line and 'enx' not in line:
        NIC = line
        break

# Check for USB NIC
USBNICFOUND = ''
for line in USBNIC:
    if 'lo' not in line and 'vir' not in line and 'wl' not in line and NIC not in line:
        USBNICFOUND = line
        break

# start building the interfaces config
FILESTRING = "auto lo\n"
FILESTRING += "\n"
FILESTRING += "iface lo inet loopback\n"
FILESTRING += "allow-hotplug " + NIC + "\n"
FILESTRING += "\n"

# 1 x NIC DHCP
if TOTAL == 1:
    FILESTRING += "iface " + NIC + " inet dhcp\n"

# 2 x NIC DHCP
elif TOTAL == 3:
    FILESTRING += "iface " + NIC + " inet dhcp\n"
    if USBNICFOUND:
        IPADDR2 = sys.argv[1]
        if not validate(IPADDR2):
            IPADDR2 = '169.254.1.1'
        IPMASK2 = sys.argv[2]
        if not validate(IPMASK2):
            IPMASK2 = '255.255.0.0'

        SUBTMP = IPMASK2.split('.')
        IPTMP = IPADDR2.split('.')

        for i in range(4):
            if int(SUBTMP[i]) != 255:
                x = 0
                IPRANGE = 256 - int(SUBTMP[i])
                while x < int(IPTMP[i]):
                    x = x + IPRANGE
                if x > int(IPTMP[i]):
                    x = x - IPRANGE
                IPTMP[i] = str(x)
        IPNETWORK2 = IPTMP[0] + "." + IPTMP[1] + "." + IPTMP[2] + "." + IPTMP[3]

        IPTMP = IPADDR2.split('.')

        for i in range(4):
            if int(SUBTMP[i]) != 255:
                x = 256 - int(SUBTMP[i])
                y = math.floor(int(IPTMP[i]) / x)
                y = (((y * x) + x) - 1)
                IPTMP[i] = str(y)
        IPCAST2 = IPTMP[0] + '.' + IPTMP[1] + '.' + IPTMP[2] + '.' + IPTMP[3]

        FILESTRING += "\nauto " + USBNICFOUND + "\n"
        FILESTRING += 'allow-hotplug ' + USBNICFOUND + '\n'
        FILESTRING += "iface " + USBNICFOUND + " inet static\n"
        FILESTRING += "address " + IPADDR2 + "\n"
        FILESTRING += "netmask " + IPMASK2 + "\n"
        FILESTRING += "network " + IPNETWORK2 + "\n"
        FILESTRING += "broadcast " + IPCAST2 + "\n"

# 1 x NIC STATIC
elif TOTAL == 7:
    IPADDR = sys.argv[1]
    if not validate(IPADDR):
        IPADDR = '169.254.1.1'
    IPMASK = sys.argv[2]
    if not validate(IPMASK):
        IPMASK = '255.255.0.0'
    IPGATE = sys.argv[3]
    if not validate(IPGATE):
        IPGATE = '169.254.1.254'
    IPNETWORK = sys.argv[4]
    if not validate(IPNETWORK):
        IPNETWORK = '169.254.0.0'
    IPCAST = sys.argv[5]
    if not validate(IPCAST):
        IPCAST = '169.254.255.255'
    IPDNS = sys.argv[6]
    if not validate(IPDNS):
        IPDNS = '8.8.8.8'

    FILESTRING += "iface " + NIC + " inet static\n"
    FILESTRING += "address " + IPADDR + "\n"
    FILESTRING += "netmask " + IPMASK + "\n"
    FILESTRING += "network " + IPNETWORK + "\n"
    FILESTRING += "broadcast " + IPCAST + "\n"
    FILESTRING += "gateway " + IPGATE + "\n"
    FILESTRING += "dns-nameservers " + IPDNS + "\n"

    FILENAME = "/etc/resolv.conf"
    FILE = open(FILENAME, "w")
    FILE.write("# Generated by config.sh\n")
    FILE.write("nameserver " + IPDNS)
    FILE.close()

# 2 x NIC STATIC
elif TOTAL == 9:
    IPADDR = sys.argv[1]
    if not validate(IPADDR):
        IPADDR = '192.168.1.1'
    IPMASK = sys.argv[2]
    if not validate(IPMASK):
        IPMASK = '255.255.255.0'
    IPGATE = sys.argv[3]
    if not validate(IPGATE):
        IPGATE = '192.168.1.254'
    IPNETWORK = sys.argv[4]
    if not validate(IPNETWORK):
        IPNETWORK = '192.168.1.0'
    IPCAST = sys.argv[5]
    if not validate(IPCAST):
        IPCAST = '192.168.1.255'
    IPDNS = sys.argv[6]
    if not validate(IPDNS):
        IPDNS = '8.8.8.8'

    FILESTRING += "iface " + NIC + " inet static\n"
    FILESTRING += "address " + IPADDR + "\n"
    FILESTRING += "netmask " + IPMASK + "\n"
    FILESTRING += "network " + IPNETWORK + "\n"
    FILESTRING += "broadcast " + IPCAST + "\n"
    FILESTRING += "gateway " + IPGATE + "\n"
    FILESTRING += "dns-nameservers " + IPDNS + "\n"

    if USBNICFOUND:
        IPADDR2 = sys.argv[7]
        if not validate(IPADDR2):
            IPADDR2 = '169.254.1.1'
        IPMASK2 = sys.argv[8]
        if not validate(IPMASK2):
            IPMASK2 = '255.255.0.0'

        SUBTMP = IPMASK2.split('.')
        IPTMP = IPADDR2.split('.')

        for i in range(4):
            if int(SUBTMP[i]) != 255:
                x = 0
                IPRANGE = 256 - int(SUBTMP[i])
                while x < int(IPTMP[i]):
                    x = x + IPRANGE
                if x > int(IPTMP[i]):
                    x = x - IPRANGE
                IPTMP[i] = str(x)
        IPNETWORK2 = IPTMP[0] + "." + IPTMP[1] + "." + IPTMP[2] + "." + IPTMP[3]

        IPTMP = IPADDR2.split('.')

        for i in range(4):
            if int(SUBTMP[i]) != 255:
                x = 256 - int(SUBTMP[i])
                y = math.floor(int(IPTMP[i]) / x)
                y = (((y * x) + x) - 1)
                IPTMP[i] = str(y)
        IPCAST2 = IPTMP[0] + '.' + IPTMP[1] + '.' + IPTMP[2] + '.' + IPTMP[3]

        FILESTRING += "\nauto " + USBNICFOUND + "\n"
        FILESTRING += 'allow-hotplug ' + USBNICFOUND + '\n'
        FILESTRING += "iface " + USBNICFOUND + " inet static\n"
        FILESTRING += "address " + IPADDR2 + "\n"
        FILESTRING += "netmask " + IPMASK2 + "\n"
        FILESTRING += "network " + IPNETWORK2 + "\n"
        FILESTRING += "broadcast " + IPCAST2 + "\n"

    FILENAME = "/etc/resolv.conf"
    FILE = open(FILENAME, "w")
    FILE.write("nameserver " + IPDNS)
    FILE.close()

FILENAME = "/opt/director/tmp"
FILE = open(FILENAME, "w")
FILE.write(FILESTRING)
FILE.close()

os.system('mv /etc/network/interfaces /etc/network/interfaces.bak')
os.system('mv /opt/director/tmp /etc/network/interfaces')

DIR = '/var/lib/dhcp/'
if os.path.isdir(DIR):
    if os.listdir(DIR):
        os.system('rm ' + DIR + '*')
