#!/usr/bin/python3
import sys
import os
import os.path

# 'config.sh [ip][mask][gate][network][cast]

# Hardware can report the NIC's as different names as a result of the BIOS so we need to find the name of the actual LAN NIC
# NUC LAN NIC = enp2s0
NIC = os.popen('ls /sys/class/net').read()
NIC = NIC.split('\n')
for line in NIC:
    if 'lo' not in line and 'vir' not in line and 'wl' not in line:
        NIC = line
        break


def validate(ipaddress):
    iparray = ipaddress.split('.')
    if len(iparray) != 4:
        return False
    for ipdigit in iparray:
        if not ipdigit.isdigit():
            return False
        i = int(ipdigit)
        if i < 0 or i > 255:
            return False
    return True

TOTAL = len(sys.argv)

if TOTAL > 1:
    IPADDR = sys.argv[1]
    if not validate(IPADDR):
        IPADDR = '169.254.1.1'
else:
    IPADDR = '169.254.1.1'

if TOTAL > 2:
    IPMASK = sys.argv[2]
    if not validate(IPMASK):
        IPMASK = '255.255.0.0'
else:
    IPMASK = '255.255.0.0'

if TOTAL > 3:
    IPGATE = sys.argv[3]
    if not validate(IPGATE):
        IPGATE = '169.254.1.254'
else:
    IPGATE = '169.254.1.254'

if TOTAL > 4:
    IPNETWORK = sys.argv[4]
    if not validate(IPNETWORK):
        IPNETWORK = '169.254.0.0'
else:
    IPNETWORK = '169.254.0.0'

if TOTAL > 5:
    IPCAST = sys.argv[5]
    if not validate(IPCAST):
        IPCAST = '169.254.255.255'
else:
    IPCAST = '169.254.255.255'

FILESTRING = "auto lo\n"
FILESTRING += "\n"
FILESTRING += "iface lo inet loopback\n"
FILESTRING += "allow-hotplug " + NIC + "\n"
FILESTRING += "\n"
if TOTAL < 2:  # 'DHCP is to be set
    FILESTRING += "iface " + NIC + " inet dhcp\n"
else:
    FILESTRING += "iface " + NIC + " inet static\n"
    FILESTRING += "address " + IPADDR + "\n"
    FILESTRING += "netmask " + IPMASK + "\n"
    FILESTRING += "network " + IPNETWORK + "\n"
    FILESTRING += "broadcast " + IPCAST + "\n"
    FILESTRING += "gateway " + IPGATE + "\n"

FILENAME = "/opt/director/tmp"
FILE = open(FILENAME, "w")
FILE.write(FILESTRING)
FILE.close()

os.system('mv /etc/network/interfaces /etc/network/interfaces.bak')
os.system('mv /opt/director/tmp /etc/network/interfaces')

DIR = '/var/lib/dhcp/'
if os.path.isdir(DIR):
    if os.listdir(DIR):
        os.system('rm ' + DIR + '*')
